
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.10',
    'branch_nick': 'ltsbranch-removal-of-fts3-transfertool',
    'revision_id': 'c084fb86282f146b3631dcab949cc260826c62a4',
    'revno': 8648
}
